@@ -12,7 +12,6 @@
 # language governing permissions and limitations under the License.
 
 import re
-
 from awscli.customizations.commands import BasicCommand
 from awscli.customizations.emr import applicationutils
 from awscli.customizations.emr import argumentschema
@@ -37,6 +36,8 @@ class CreateCluster(Command):
     ARG_TABLE = [
         {'name': 'release-label',
          'help_text': helptext.RELEASE_LABEL},
+        {'name': 'os-release-label',
+         'help_text': helptext.OS_RELEASE_LABEL},
         {'name': 'ami-version',
          'help_text': helptext.AMI_VERSION},
         {'name': 'instance-groups',
@@ -59,6 +60,8 @@ class CreateCluster(Command):
          'help_text': helptext.CLUSTER_NAME},
         {'name': 'log-uri',
          'help_text': helptext.LOG_URI},
+        {'name': 'log-encryption-kms-key-id',
+         'help_text': helptext.LOG_ENCRYPTION_KMS_KEY_ID},
         {'name': 'service-role',
          'help_text': helptext.SERVICE_ROLE},
         {'name': 'auto-scaling-role',
@@ -120,7 +123,16 @@ class CreateCluster(Command):
          'help_text': helptext.KERBEROS_ATTRIBUTES},
         {'name': 'step-concurrency-level',
          'cli_type_name': 'integer',
-         'help_text': helptext.STEP_CONCURRENCY_LEVEL}
+         'help_text': helptext.STEP_CONCURRENCY_LEVEL},
+        {'name': 'managed-scaling-policy',
+         'schema': argumentschema.MANAGED_SCALING_POLICY_SCHEMA,
+         'help_text': helptext.MANAGED_SCALING_POLICY},
+        {'name': 'placement-group-configs',
+         'schema': argumentschema.PLACEMENT_GROUP_CONFIGS_SCHEMA,
+         'help_text': helptext.PLACEMENT_GROUP_CONFIGS},
+        {'name': 'auto-termination-policy',
+         'schema': argumentschema.AUTO_TERMINATION_POLICY_SCHEMA,
+         'help_text': helptext.AUTO_TERMINATION_POLICY}
     ]
     SYNOPSIS = BasicCommand.FROM_FILE('emr', 'create-cluster-synopsis.txt')
     EXAMPLES = BasicCommand.FROM_FILE('emr', 'create-cluster-examples.rst')
@@ -189,6 +201,14 @@ class CreateCluster(Command):
             params, 'AdditionalInfo', parsed_args.additional_info)
         emrutils.apply_dict(params, 'LogUri', parsed_args.log_uri)
 
+        if parsed_args.os_release_label is not None:
+            emrutils.apply_dict(params, 'OSReleaseLabel',
+                parsed_args.os_release_label)
+
+        if parsed_args.log_encryption_kms_key_id is not None:
+            emrutils.apply_dict(params, 'LogEncryptionKmsKeyId',
+                parsed_args.log_encryption_kms_key_id)
+
         if parsed_args.use_default_roles is True:
             parsed_args.service_role = EMR_ROLE_NAME
             if parsed_args.ec2_attributes is None:
@@ -336,6 +356,20 @@ class CreateCluster(Command):
         if parsed_args.step_concurrency_level is not None:
             params['StepConcurrencyLevel'] = parsed_args.step_concurrency_level
 
+        if parsed_args.managed_scaling_policy is not None:
+            emrutils.apply_dict(
+                params, 'ManagedScalingPolicy', parsed_args.managed_scaling_policy)
+
+        if parsed_args.placement_group_configs is not None:
+            emrutils.apply_dict(
+                params, 'PlacementGroupConfigs',
+                parsed_args.placement_group_configs)
+
+        if parsed_args.auto_termination_policy is not None:
+            emrutils.apply_dict(
+                params, 'AutoTerminationPolicy',
+                parsed_args.auto_termination_policy)
+
         self._validate_required_applications(parsed_args)
 
         run_job_flow_response = emrutils.call(
@@ -463,7 +497,7 @@ class CreateCluster(Command):
             bootstrap_actions.append(ba_config)
 
         result = cluster_ba_list + bootstrap_actions
-        if len(result) > 0:
+        if result:
             cluster['BootstrapActions'] = result
 
         return cluster
@@ -485,9 +519,9 @@ class CreateCluster(Command):
             args=args)
 
     def _update_cluster_dict(self, cluster, key, value):
-        if key in cluster.keys():
+        if key in cluster:
             cluster[key] += value
-        elif value is not None and len(value) > 0:
+        elif value:
             cluster[key] = value
         return cluster
 
@@ -520,14 +554,14 @@ class CreateCluster(Command):
             if constants.HBASE not in specified_apps:
                 missing_apps.add(constants.HBASE.title())
 
-        if len(missing_apps) != 0:
+        if missing_apps:
             raise exceptions.MissingApplicationsError(
                 applications=missing_apps)
 
     def _get_missing_applications_for_steps(self, specified_apps, parsed_args):
         allowed_app_steps = set([constants.HIVE, constants.PIG,
                                  constants.IMPALA])
-        missing_apps = set([])
+        missing_apps = set()
         if parsed_args.steps is not None:
             for step in parsed_args.steps:
                 if len(missing_apps) == len(allowed_app_steps):
